@@ -2,38 +2,28 @@
 develop and setup helper functions
 ==================================
 
-This core portion of the 'de' namespace is
-providing helper functions for the development and
-the setup of namespace portions.
+This core portion of the 'de' namespace is providing helper functions for the development and the setup of namespace
+portions.
 
 
 optional dependencies
 ---------------------
 
 .. note::
-    This portion has two optional dependencies that
-    are only needed for special cases, like setup
-    hooks or template processing.
+    This portion has two optional dependencies that are only needed for special cases, like setup hooks or template
+    processing.
 
-The :mod:`ae.literal` portion of the 'ae' namespace
-is optionally needed for
-:func:`de.core.replace_with_file_content_or_default`
-(which is currently used only used by the 'ae'
-namespace root package for to patch the .gitlab-ci.yml
-file for the portions ae.db_pg, ae.gui_app
-and ae.kivy_app).
+The :mod:`ae.literal` portion of the 'ae' namespace is optionally needed for
+:func:`de.core.replace_with_file_content_or_default` (which is currently used only used by the 'ae' namespace root
+package for to patch the .gitlab-ci.yml file for the portions ae.db_pg, ae.gui_app and ae.kivy_app).
 
-The :mod:`ae.inspector` portion of the 'ae' namespace
-is optionally needed as fallback for
-:func:`de.core.replace_with_file_content_or_default`
-and for :func:`de.core.nev_update_hook`
-(which is currently not used by any ae portion).
+The :mod:`ae.inspector` portion of the 'ae' namespace is optionally needed as fallback for
+:func:`de.core.replace_with_file_content_or_default` and for :func:`de.core.nev_update_hook` (which is currently not
+used by any ae portion).
 
-Therefore if your namespace portion or app is using
-one of these two helper functions than the containing
-repository project has to include :mod:`ae.inspector`
-respective :mod:`ae.literal` explicitly in their
-requirements.txt respective test_requirements.txt files.
+Therefore if your namespace portion or app is using one of these two helper functions than the containing repository
+project has to include :mod:`ae.inspector` respective :mod:`ae.literal` explicitly in their requirements.txt respective
+test_requirements.txt files.
 """
 import glob
 import os
@@ -41,7 +31,7 @@ import re
 from typing import Callable, Dict, List, Optional, Tuple, Union
 
 
-__version__ = '0.0.18'       # ALSO CHANGE IN setup.py
+__version__ = '0.0.21'       # ALSO CHANGE IN setup.py
 
 
 NevVarType = Union[str, List[str]]
@@ -66,6 +56,8 @@ TEMPLATE_PLACEHOLDER_ID_SUFFIX = "#("                   #: template id suffix ma
 TEMPLATE_PLACEHOLDER_ARGS_SUFFIX = ")#"                 #: template args suffix marker
 TEMPLATE_INCLUDE_FILE_PLACEHOLDER_ID = "IncludeFile"    #: placeholder id (func:`replace_with_file_content_or_default`)
 
+TESTS_FOLDER = 'tests'                                  #: folder name to store unit/integration tests
+
 VERSION_PATCH_PARSER = re.compile(r"(^__version__ = ['\"]\d*[.])(\d*)([.]\d+[a-z]*['\"])", re.MULTILINE)
 """ pre-compiled regular expression for to detect and bump the namespace/package version numbers of version string """
 
@@ -113,6 +105,28 @@ def file_content(file_name: str) -> str:
         return file_handle.read()
 
 
+def find_package_data(namespace_name: str, portion_name: str) -> List[str]:
+    """ find kv lang files, i18n translation texts, images and sound resource files of package portion.
+
+    :param namespace_name:      name space name/id.
+    :param portion_name:        portion name.
+    :return:                    list of resource files for to be used in the setup package_data kwarg value.
+    """
+    pgk_path = os.path.join(namespace_name, portion_name)
+    files = list()
+
+    for file in glob.glob(os.path.join(pgk_path, "**", "*.kv"), recursive=True):
+        if os.path.isfile(file):
+            files.append(os.path.relpath(file, pgk_path))
+
+    for resource_folder in ('img', 'loc', 'snd'):
+        for file in glob.glob(os.path.join(pgk_path, resource_folder, "**", "*"), recursive=True):
+            if os.path.isfile(file):
+                files.append(os.path.relpath(file, pgk_path))
+
+    return files
+
+
 def load_requirements(namespace_name: str, nev: NevType, path: str) -> List[str]:
     """ load requirements from *requirements.txt and return list of portions package names.
 
@@ -125,11 +139,11 @@ def load_requirements(namespace_name: str, nev: NevType, path: str) -> List[str]
     requirements_file = os.path.join(path, nev_str(nev, 'REQ_FILE_NAME'))
     if os.path.exists(requirements_file):
         dev_require.extend(
-            _ for _ in file_content(requirements_file).strip().split('\n') if not _.startswith('#'))
+            _ for _ in file_content(requirements_file).strip().split('\n') if _ and not _.startswith('#'))
     if 'de_core' not in dev_require:
         dev_require.append('de_core')
     nev['docs_require'] = [_ for _ in dev_require if _.startswith('sphinx_')]
-    nev['install_require'] = [_ for _ in dev_require if not _.startswith('sphinx_')]
+    nev['install_require'] = [_ for _ in dev_require if _ and not _.startswith('sphinx_')]
     # if a namespace portion is needed for the setup process then use hyphen/dash instead of underscore
     # e.g. ae-literal instead of ae_literal (then ae.literal will be included in setup_require)
     nev['setup_require'] = [_ for _ in nev['install_require'] if not _.startswith(f'{namespace_name}_')]
@@ -203,6 +217,7 @@ def namespace_env_vars(namespace_name: str, pkg_root_path: str = "", old_nev: Op
 
     if portion_type:    # additional package info exclusively by portions (modules or sub-packages)
         nev['find_packages_include'] = [namespace_name + (".*" if portion_type == _PT_PKG else "")]
+        nev['package_resources'] = find_package_data(namespace_name, portion_name)
     else:               # provide additional package info exclusively used by the root package templates
         namespace_len = len(namespace_name)
         pypi_refs = list()
@@ -382,9 +397,13 @@ def replace_with_file_content_or_default(args_str: str) -> str:
             try:
                 # noinspection PyUnresolvedReferences
                 from ae.inspector import try_eval       # type: ignore  # mypy
+                # noinspection PyUnresolvedReferences
+                from ae.base import UNSET               # type: ignore  # mypy
+
                 ret = try_eval(default[0], ignored_exceptions=(Exception, ))
-                if ret is None:
+                if ret is UNSET:
                     ret = default[0]
+
             except ImportError:
                 ret = default[0]
     else:
